{% extends "base.html" %}
{% block title %}Search — cclog{% endblock %}

{% block content %}
<div class="page-header">
    <h1>Search</h1>
    <p class="subtitle">Full-text search across all conversations</p>
</div>

<div class="search-container">
    <div class="search-input-wrap">
        <svg class="search-icon" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5"><circle cx="11" cy="11" r="8"/><path d="M21 21l-4.35-4.35"/></svg>
        <input type="text" id="search-input" class="search-input" placeholder="Search conversations..." value="{{ query }}" autofocus />
        <kbd class="search-kbd">/</kbd>
    </div>
    <div id="search-results" class="search-results"></div>
</div>
{% endblock %}
